Index: svn_diff.rb
===================================================================
--- svn_diff.rb	(revision 3117)
+++ svn_diff.rb	(working copy)
@@ -11,22 +11,58 @@
 #		command		= ARGV[1]
 		output_path	= File.basename(target_path) + ".diff"
 
-		TextMate::call_with_progress(:title => command,
-									:message => "Accessing Subversion Repository…",
-									:output_filepath => output_path) do
-			have_data = false
-			
-			# idea here is to stream the data rather than submit it in one big block
-			%x{"#{svn}" diff --diff-cmd diff "-r#{revision}" "#{target_path}"}.each_line do |line|
-				have_data = true unless line.empty?
-				puts line
-			end
+		have_data = false
+
+    if custom_diff? and ENV['TM_SVN_DIFF_CMD'].nil?
+  		TextMate::call_with_progress(:title => command,
+  									:message => "Accessing Subversion Repository…",
+  									:output_filepath => output_path) do
+  			# idea here is to stream the data rather than submit it in one big block
+  			%x{"#{svn}" diff "-r#{revision}" "#{target_path}"}.each_line do |line|
+  			  # Exclude empty lines and the header lines generated by svn
+  			  if not line.empty? and not line =~ /Index: #{target_path}/ and not line =~ /=+/
+  				  have_data = true
+  				  puts line
+  				end
+  			end
+
+        # Did the diff command fail?
+        if $? != 0
+          exit 206  # The command failed; show its output as a tooltip
+        else
+  			  exit 200 unless have_data   # The command succeeded; show its output (if any) in an editor window
+  			end
+  		end
+    else
+  		TextMate::call_with_progress(:title => command,
+  									:message => "Accessing Subversion Repository…",
+  									:output_filepath => output_path) do
+  			diff_cmd ||= ENV['TM_SVN_DIFF_CMD']
+  			# idea here is to stream the data rather than submit it in one big block
+  			%x{"#{svn}" diff --diff-cmd #{diff_cmd} "-r#{revision}" "#{target_path}"}.each_line do |line|
+  				have_data = true unless line.empty?
+  				puts line
+  			end
 			
-			if not have_data then
-				# switch to tooltip output to report lack of differences
-				puts "No differences found."
-				exit 206;
-			end
-		end
+  			if not have_data then
+  				# switch to tooltip output to report lack of differences
+  				puts "No differences found."
+  				exit 206
+  			end
+  		end
+  	end
 	end
+
+  # Returns true if ~/.subversion/config contains an uncommented entry for diff-cmd
+  def Subversion.custom_diff?
+    config_file = ENV['HOME'] + "/.subversion/config"
+      
+    if File.exists?(config_file)
+      IO.foreach(config_file) do |line|
+        return true if line =~ /^\s?diff-cmd\s?=\s?(.*)/
+      end
+    end
+    
+    return false
+  end  
 end
